@@ -12,6 +12,8 @@ use std::{
     fmt,
 };
 
+#[cfg(feature = "ffi")]
+use crate::callable::ffi::*;
 use crate::*;
 
 /// A Tag is used to categorize a job.
@@ -196,7 +198,7 @@ impl Job {
         } else if num_vals == 2 && self.unit == Some(Minute) {
             second = time_vals[1].parse().unwrap();
         } else if num_vals == 2 && self.unit == Some(Hour) {
-            minute = if time_vals[0].len() > 0 {
+            minute = if !time_vals[0].is_empty() {
                 time_vals[0].parse().unwrap()
             } else {
                 0
@@ -291,6 +293,18 @@ impl Job {
         Ok(())
     }
 
+    #[cfg(feature = "ffi")]
+    pub fn run_extern(
+        mut self,
+        scheduler: &mut Scheduler,
+        job: extern "C" fn() -> (),
+    ) -> Result<()> {
+        self.job = Some(Box::new(ExternUnitToUnit::new("job", job)));
+        self.schedule_next_run()?;
+        scheduler.add_job(self);
+        Ok(())
+    }
+
     /// Specify the work function with one argument that will execute when this job runs and add it to the schedule
     ///
     /// ```rust
@@ -322,6 +336,23 @@ impl Job {
         Ok(())
     }
 
+    // NOTE: Doesn't work, can't use a generic fn as FFI boundary interface
+    // #[cfg(feature = "ffi")]
+    // pub fn run_one_arg_extern<T>(
+    //     mut self,
+    //     scheduler: &mut Scheduler,
+    //     job: extern "C" fn(T) -> (),
+    //     arg: T,
+    // ) -> Result<()>
+    // where
+    //     T: 'static + Clone,
+    // {
+    //     self.job = Some(Box::new(ExternOneToUnit::new("job_one_arg", job, arg)));
+    //     self.schedule_next_run()?;
+    //     scheduler.add_job(self);
+    //     Ok(())
+    // }
+
     /// Specify the work function with two arguments that will execute when this job runs and add it to the schedule
     /// ```rust
     /// # use skedge::*;
@@ -471,6 +502,7 @@ impl Job {
     /// # Ok(())
     /// # }
     /// ```
+    #[allow(clippy::too_many_arguments)]
     pub fn run_five_args<T, U, V, W, X>(
         mut self,
         scheduler: &mut Scheduler,
@@ -532,6 +564,7 @@ impl Job {
     /// # Ok(())
     /// # }
     /// ```
+    #[allow(clippy::too_many_arguments)]
     pub fn run_six_args<T, U, V, W, X, Y>(
         mut self,
         scheduler: &mut Scheduler,
